==> zio-aws-route53resolver_2.12-6.20.149.1-sources.jar: zio/aws/route53resolver/model/CreateFirewallRuleResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateFirewallRuleResponse(
    firewallRule: Optional[zio.aws.route53resolver.model.FirewallRule] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse = {
    import CreateFirewallRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse
      .builder()
      .optionallyWith(firewallRule.map(value => value.buildAwsValue()))(
        _.firewallRule
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.CreateFirewallRuleResponse.ReadOnly =
    zio.aws.route53resolver.model.CreateFirewallRuleResponse
      .wrap(buildAwsValue())
}
object CreateFirewallRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53resolver.model.CreateFirewallRuleResponse =
      zio.aws.route53resolver.model
        .CreateFirewallRuleResponse(firewallRule.map(value => value.asEditable))
    def firewallRule
        : Optional[zio.aws.route53resolver.model.FirewallRule.ReadOnly]
    def getFirewallRule: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.FirewallRule.ReadOnly
    ] = AwsError.unwrapOptionField("firewallRule", firewallRule)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse
  ) extends zio.aws.route53resolver.model.CreateFirewallRuleResponse.ReadOnly {
    override val firewallRule
        : Optional[zio.aws.route53resolver.model.FirewallRule.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.firewallRule())
        .map(value => zio.aws.route53resolver.model.FirewallRule.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse
  ): zio.aws.route53resolver.model.CreateFirewallRuleResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53resolver_2.13-5.17.128.1-sources.jar: zio/aws/route53resolver/model/CreateFirewallRuleResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateFirewallRuleResponse(
    firewallRule: Option[zio.aws.route53resolver.model.FirewallRule] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse = {
    import CreateFirewallRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse
      .builder()
      .optionallyWith(firewallRule.map(value => value.buildAwsValue()))(
        _.firewallRule
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.CreateFirewallRuleResponse.ReadOnly =
    zio.aws.route53resolver.model.CreateFirewallRuleResponse
      .wrap(buildAwsValue())
}
object CreateFirewallRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53resolver.model.CreateFirewallRuleResponse =
      zio.aws.route53resolver.model
        .CreateFirewallRuleResponse(firewallRule.map(value => value.asEditable))
    def firewallRule
        : Option[zio.aws.route53resolver.model.FirewallRule.ReadOnly]
    def getFirewallRule: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.FirewallRule.ReadOnly
    ] = AwsError.unwrapOptionField("firewallRule", firewallRule)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse
  ) extends zio.aws.route53resolver.model.CreateFirewallRuleResponse.ReadOnly {
    override val firewallRule
        : Option[zio.aws.route53resolver.model.FirewallRule.ReadOnly] = scala
      .Option(impl.firewallRule())
      .map(value => zio.aws.route53resolver.model.FirewallRule.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleResponse
  ): zio.aws.route53resolver.model.CreateFirewallRuleResponse.ReadOnly =
    new Wrapper(impl)
}
